Mimi

Struct Mimi 

pub struct Mimi<T: Tensor> {
    pub quantizer: SplitResidualVectorQuantizer<T>,
    /* private fields */
}
Mimi audio tokenizer.

Fields

quantizer: SplitResidualVectorQuantizer<T>

Split residual vector quantizer.

Implementations

Source

impl<T: Tensor> Mimi<T>

pub fn new(config: Config, context: &T::Context) -> Result<Self, Error>

Creates an unloaded Mimi tokenizer from config.

pub fn mimi_config(&self) -> &Config

Returns the Mimi configuration.

pub fn encode_latent( &mut self, latent: &T, context: &T::Context, ) -> Result<T, Error>

Encodes latent frames shaped [batch, 512, frames] into Mimi tokens.

pub fn encode(&mut self, pcm: &T, context: &T::Context) -> Result<T, Error>

Encodes PCM shaped [batch, 1, samples] into Mimi tokens [batch, codebooks, frames].

pub fn reset_encode_state(&mut self)

Resets state used by Mimi::encode_step.

pub fn encode_step( &mut self, pcm: &T, context: &T::Context, ) -> Result<Option<T>, Error>

Encodes one PCM frame into the next Mimi token frame.

Accepts PCM shaped [batch, 1, samples]. Returns None until the streaming encoder has enough samples to emit a complete codec frame.

pub fn decode_latent( &mut self, codes: &T, context: &T::Context, ) -> Result<T, Error>

Decodes Mimi tokens shaped [batch, codebooks, frames] into latent frames.

pub fn decode(&mut self, codes: &T, context: &T::Context) -> Result<T, Error>

Decodes Mimi tokens shaped [batch, codebooks, frames] into PCM [batch, 1, samples].

pub fn reset_decode_state(&mut self)

Resets state used by Mimi::decode_step.

pub fn decode_step( &mut self, codes: &T, context: &T::Context, ) -> Result<T, Error>

Decodes one Mimi token frame into the next PCM chunk.

Accepts codes shaped [batch, codebooks] or [batch, codebooks, 1].