PreparedMimiArtifact

Struct PreparedMimiArtifact 

pub struct PreparedMimiArtifact { /* private fields */ }
Header-admitted Mimi artifact with an immutable exact parameter plan.

Implementations

Source

impl PreparedMimiArtifact

pub const fn config(&self) -> &Config

Released configuration fixed by neutral preparation.

pub fn requirements(&self) -> &[MimiParameterRequirement]

Exact full-checkpoint requirements, including inactive codebooks.

pub fn bindings(&self) -> &[WeightBinding]

Active generic runtime bindings selected by preparation.

pub fn select<B>( self, ) -> Result<SelectedMimiArtifact<B>, MimiConstructionError<B::ParameterError>>
where B: ParameterBackend<Parameter = <B as NeuralBackend>::Tensor>,

Performs backend mechanism admission without reading payloads or constructing backend-native Mimi tensors.